[![Actions Status](https://github.com/qtoggle/qtoggleserver/workflows/Release/badge.svg)](https://github.com/qtoggle/qtoggleserver/actions)

**qToggleServer** is a fully fledged [qToggle](https://github.com/qtoggle/docs) implementation written in Python.

Check out the [Getting Started](https://github.com/qtoggle/qtoggleserver/wiki/Getting-Started) wiki page to install and get started with qToggleServer.
